##  [](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/edge_update_schedules/operation/EdgeUpdateScheduleDelete)Deletes an Edge Update Schedule
**Access policy** : administrator
##### Authorizations:
_ApiKeyAuth_ _jwt_
##### path Parameters
idrequired |  integer EdgeUpdate Id
---|---
### Responses
**204**
No Content
**500**
Internal Server Error
delete/edge_update_schedules/{id}
https://api-docs.portainer.io/api/edge_update_schedules/{id}
